--input-file - входной файл с заказ, в котором категория, сумма и количество

--output-file - выходной файл, куда будет записан чек в формате txt

Пример команды: python -m autocheck --input-file data/order.json --output-file rrr.txt

С egg возникают проблемы с загрузкой на pypi(ERROR    HTTPError: 400 Bad Request from https://upload.pypi.org/legacy/
         Invalid value for filetype. Error: Use a known file type.
)